@@ -97,3 +97,30 @@ class ZRedis:
 
     def rpush(self, key, *values):
         return self.client.rpush(key, *values)
+
+
+def redis_blpop(client, keys, timeout=0, retry_interval=60):
+    while True:
+        try:
+            return redis_decode(client.blpop(keys, timeout=timeout))
+        except:
+            import time
+            time.sleep(retry_interval)
+
+
+def redis_brpop(client, keys, timeout=0, retry_interval=60):
+    while True:
+        try:
+            return redis_decode(client.brpop(keys, timeout=timeout))
+        except:
+            import time
+            time.sleep(retry_interval)
+
+
+def brpoplpush(client, src, dst, timeout=0, retry_interval=60):
+    while True:
+        try:
+            return redis_decode(client.brpoplpush(src, dst, timeout))
+        except:
+            import time
+            time.sleep(retry_interval)
